@@ -146,6 +146,9 @@ struct NautilusIconContainerDetails {
 	guint keyboard_icon_reveal_timer_id;
 	NautilusIcon *keyboard_icon_to_reveal;
 
+	/* Used to coalesce selection changed signals in some cases */
+	guint selection_changed_id;
+	
 	/* If a request is made to reveal an unpositioned icon we remember
 	 * it and reveal it once it gets positioned (in relayout).
 	 */
@@ -241,6 +244,9 @@ struct NautilusIconContainerDetails {
 
         /* Set to TRUE after first allocation has been done */
 	gboolean has_been_allocated;
+
+	int size_allocation_count;
+	guint size_allocation_count_id;
 	
 	/* Is the container fixed or resizable */
 	gboolean is_fixed_size;
