@@ -226,7 +226,7 @@ show_selection_idle_callback (gpointer callback_data)
 		(view->details->sort_model, path);
 	gtk_tree_path_free (path);
 	gtk_tree_view_set_cursor (view->details->tree_widget, sort_path, NULL, FALSE);
-	if (GTK_WIDGET_REALIZED (view->details->tree_widget)) {
+	if (gtk_widget_get_realized (GTK_WIDGET (view->details->tree_widget))) {
 		gtk_tree_view_scroll_to_cell (view->details->tree_widget, sort_path, NULL, FALSE, 0, 0);
 	}
 	gtk_tree_path_free (sort_path);
@@ -732,14 +732,13 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 		} else {
 			gtk_widget_hide (view->details->popup_delete);
 		}
-		
+
 		mount = fm_tree_model_get_mount_for_root_node_file (view->details->child_model, view->details->popup_file);
 		if (mount) {
-			/* TODO: show both unmount and eject if there are more than one volume for the drive */
 			show_unmount = g_mount_can_unmount (mount);
 			show_eject = g_mount_can_eject (mount);
-		} 
-		
+		}
+
 		if (show_unmount) {
 			gtk_widget_show (view->details->popup_unmount);
 		} else {
@@ -800,13 +799,6 @@ fm_tree_view_activate_file (FMTreeView *view,
 
 	cancel_activation (view);
 
-	if (view->details->activation_flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB &&
-	    !eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ENABLE_TABS)) {
-		view->details->activation_flags &= ~NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
-		view->details->activation_flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
-	}
-
-
 	view->details->activation_file = nautilus_file_ref (file);
 	view->details->activation_flags = flags;
 		
@@ -1530,6 +1522,7 @@ fm_tree_view_init (FMTreeView *view)
 					GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_hadjustment (GTK_SCROLLED_WINDOW (view), NULL);
 	gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (view), NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (view), GTK_SHADOW_IN);
 	
 	gtk_widget_show (GTK_WIDGET (view));
 
@@ -1706,8 +1699,7 @@ fm_tree_view_create (NautilusSidebarProvider *provider,
 	
 	sidebar = g_object_new (fm_tree_view_get_type (), NULL);
 	fm_tree_view_set_parent_window (sidebar, window);
-	g_object_ref (sidebar);
-	gtk_object_sink (GTK_OBJECT (sidebar));
+	g_object_ref_sink (sidebar);
 
 	return NAUTILUS_SIDEBAR (sidebar);
 }
