@@ -39,12 +39,10 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-entry.h>
 #include <libnautilus-private/nautilus-icon-dnd.h>
@@ -63,6 +61,7 @@ struct NautilusLocationEntryDetails {
 	gboolean has_special_text;
 	gboolean setting_special_text;
 	gchar *special_text;
+	NautilusLocationEntryAction secondary_action;
 };
 
 static void  nautilus_location_entry_class_init       (NautilusLocationEntryClass *class);
@@ -92,7 +91,8 @@ try_to_expand_path (gpointer callback_data)
 	
 	suffix = g_filename_completer_get_completion_suffix (entry->details->completer,
 							     user_location);
-	
+	g_free (user_location);
+
 	/* if we've got something, add it to the entry */
 	if (suffix != NULL) {
 		pos = user_location_length;
@@ -283,6 +283,24 @@ nautilus_location_entry_text_changed (NautilusLocationEntry *entry,
 	entry->details->has_special_text = FALSE;
 }
 
+static void
+nautilus_location_entry_icon_release (GtkEntry *gentry,
+				      GtkEntryIconPosition position,
+				      GdkEvent *event,
+				      gpointer unused)
+{
+	switch (NAUTILUS_LOCATION_ENTRY (gentry)->details->secondary_action) {
+	case NAUTILUS_LOCATION_ENTRY_ACTION_GOTO:
+		g_signal_emit_by_name (gentry, "activate", gentry);
+		break;
+	case NAUTILUS_LOCATION_ENTRY_ACTION_CLEAR:
+		gtk_entry_set_text (gentry, "");
+		break;
+	default:
+		g_assert_not_reached ();
+	}
+}
+
 static gboolean
 nautilus_location_entry_focus_in (GtkWidget     *widget,
 				  GdkEventFocus *event)
@@ -316,6 +334,30 @@ nautilus_location_entry_class_init (NautilusLocationEntryClass *class)
 	object_class->destroy = destroy;
 }
 
+void
+nautilus_location_entry_set_secondary_action (NautilusLocationEntry *entry,
+					      NautilusLocationEntryAction secondary_action)
+{
+	if (entry->details->secondary_action == secondary_action) {
+		return;
+	}
+	switch (secondary_action) {
+	case NAUTILUS_LOCATION_ENTRY_ACTION_CLEAR:
+		gtk_entry_set_icon_from_stock (GTK_ENTRY (entry), 
+					       GTK_ENTRY_ICON_SECONDARY,
+					       GTK_STOCK_CLEAR);
+		break;
+	case NAUTILUS_LOCATION_ENTRY_ACTION_GOTO:
+		gtk_entry_set_icon_from_stock (GTK_ENTRY (entry),
+					       GTK_ENTRY_ICON_SECONDARY,
+					       GTK_STOCK_GO_FORWARD);
+		break;
+	default:
+		g_assert_not_reached ();
+	}
+	entry->details->secondary_action = secondary_action;
+}
+
 static void
 nautilus_location_entry_init (NautilusLocationEntry *entry)
 {
@@ -323,7 +365,10 @@ nautilus_location_entry_init (NautilusLocationEntry *entry)
 
 	entry->details->completer = g_filename_completer_new ();
 	g_filename_completer_set_dirs_only (entry->details->completer, TRUE);
-	
+
+	nautilus_location_entry_set_secondary_action (entry,
+						      NAUTILUS_LOCATION_ENTRY_ACTION_CLEAR);
+
 	nautilus_entry_set_special_tab_handling (NAUTILUS_ENTRY (entry), TRUE);
 
 	g_signal_connect (entry, "event_after",
@@ -332,6 +377,9 @@ nautilus_location_entry_init (NautilusLocationEntry *entry)
 	g_signal_connect (entry, "notify::text",
 			  G_CALLBACK (nautilus_location_entry_text_changed), NULL);
 
+	g_signal_connect (entry, "icon-release",
+			  G_CALLBACK (nautilus_location_entry_icon_release), NULL);
+
 	g_signal_connect (entry->details->completer, "got_completion_data",
 		          G_CALLBACK (got_completion_data_callback), entry);
 }
