@@ -101,7 +101,6 @@ static void side_panel_image_changed_callback        (NautilusSidebar          *
 						      gpointer                  callback_data);
 static void always_use_location_entry_changed        (gpointer                  callback_data);
 static void always_use_browser_changed               (gpointer                  callback_data);
-static void enable_tabs_changed			     (gpointer                  callback_data);
 static void mouse_back_button_changed		     (gpointer                  callback_data);
 static void mouse_forward_button_changed	     (gpointer                  callback_data);
 static void use_extra_mouse_buttons_changed          (gpointer                  callback_data);
@@ -128,7 +127,6 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	GtkWidget *toolbar;
 	NautilusWindow *win;
 	NautilusNavigationWindowPane *pane;
-	NautilusWindowSlot *slot;
 	GtkWidget *hpaned;
 	GtkWidget *vbox;
 
@@ -139,6 +137,9 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	pane = nautilus_navigation_window_pane_new (win);
 	win->details->panes = g_list_prepend (win->details->panes, pane);
 
+	window->details->header_size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
+	gtk_size_group_set_ignore_hidden (window->details->header_size_group, FALSE);
+
 	window->details->content_paned = nautilus_horizontal_splitter_new ();
 	gtk_table_attach (GTK_TABLE (NAUTILUS_WINDOW (window)->details->table),
 			  window->details->content_paned,
@@ -171,10 +172,6 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 
 	nautilus_navigation_window_initialize_actions (window);
 
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE)) {
-		slot = create_extra_pane (window);
-	}
-
 	nautilus_navigation_window_initialize_menus (window);
 
 	ui_manager = nautilus_window_get_ui_manager (NAUTILUS_WINDOW (window));
@@ -203,10 +200,6 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER,
 						  always_use_browser_changed,
 						  window, G_OBJECT (window));
-
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_ENABLE_TABS,
-						  enable_tabs_changed,
-						  window, G_OBJECT (window));
 }
 
 static void
@@ -235,16 +228,6 @@ always_use_browser_changed (gpointer callback_data)
 	nautilus_navigation_window_update_spatial_menu_item (window);
 }
 
-static void
-enable_tabs_changed (gpointer callback_data)
-{
-	NautilusNavigationWindow *window;
-
-	window = NAUTILUS_NAVIGATION_WINDOW (callback_data);
-
-	nautilus_navigation_window_update_tab_menu_item_visibility (window);
-}
-
 /* Sanity check: highest mouse button value I could find was 14. 5 is our 
  * lower threshold (well-documented to be the one of the button events for the 
  * scrollwheel), so it's hardcoded in the functions below. However, if you have
@@ -298,7 +281,7 @@ nautilus_navigation_window_unset_focus_widget (NautilusNavigationWindow *window)
 	}
 }
 
-inline gboolean
+gboolean
 nautilus_navigation_window_is_in_temporary_navigation_bar (GtkWidget *widget,
 				NautilusNavigationWindow *window)
 {
@@ -314,7 +297,7 @@ nautilus_navigation_window_is_in_temporary_navigation_bar (GtkWidget *widget,
 	return is_in_any;
 }
 
-inline gboolean
+gboolean
 nautilus_navigation_window_is_in_temporary_search_bar (GtkWidget *widget,
 			    NautilusNavigationWindow *window)
 {
@@ -456,8 +439,14 @@ side_pane_switch_page_callback (NautilusSidePane *side_pane,
 static void
 nautilus_navigation_window_set_up_sidebar (NautilusNavigationWindow *window)
 {
+	GtkWidget *title;
+
 	window->sidebar = nautilus_side_pane_new ();
 
+	title = nautilus_side_pane_get_title (window->sidebar);
+	gtk_size_group_add_widget (window->details->header_size_group,
+				   title);
+
 	gtk_paned_pack1 (GTK_PANED (window->details->content_paned),
 			 GTK_WIDGET (window->sidebar),
 			 FALSE, TRUE);
@@ -749,10 +738,6 @@ real_sync_title (NautilusWindow *window,
 	pane = NAUTILUS_NAVIGATION_WINDOW_PANE (slot->pane);
 	notebook = NAUTILUS_NOTEBOOK (pane->notebook);
 	nautilus_notebook_sync_tab_label (notebook, slot);
-
-	if (slot->pane->is_active) {
-		nautilus_navigation_window_pane_sync_tab_menu_title (pane, slot);
-	}
 }
 
 static NautilusIconInfo *
@@ -770,7 +755,7 @@ real_sync_allow_stop (NautilusWindow *window,
 	NautilusNotebook *notebook;
 
 	navigation_window = NAUTILUS_NAVIGATION_WINDOW (window);
-	nautilus_navigation_window_set_throbber_active (navigation_window, slot->allow_stop);
+	nautilus_navigation_window_set_spinner_active (navigation_window, slot->allow_stop);
 
 	notebook = NAUTILUS_NOTEBOOK (NAUTILUS_NAVIGATION_WINDOW_PANE (slot->pane)->notebook);
 	nautilus_notebook_sync_loading (notebook, slot);
@@ -907,7 +892,7 @@ gboolean
 nautilus_navigation_window_toolbar_showing (NautilusNavigationWindow *window)
 {
 	if (window->details->toolbar != NULL) {
-		return GTK_WIDGET_VISIBLE (window->details->toolbar);
+		return gtk_widget_get_visible (window->details->toolbar);
 	}
 	/* If we're not visible yet we haven't changed visibility, so its TRUE */
 	return TRUE;
@@ -941,7 +926,7 @@ gboolean
 nautilus_navigation_window_status_bar_showing (NautilusNavigationWindow *window)
 {
 	if (NAUTILUS_WINDOW (window)->details->statusbar != NULL) {
-		return GTK_WIDGET_VISIBLE (NAUTILUS_WINDOW (window)->details->statusbar);
+		return gtk_widget_get_visible (NAUTILUS_WINDOW (window)->details->statusbar);
 	}
 	/* If we're not visible yet we haven't changed visibility, so its TRUE */
 	return TRUE;
@@ -1294,12 +1279,6 @@ nautilus_navigation_window_split_view_on (NautilusNavigationWindow *window)
 	} else {
 		nautilus_navigation_window_pane_hide_location_bar (pane, TRUE);
 	}
-
-	/* remember in gconf */
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE) &&
-	    !eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE, TRUE);
-	}
 }
 
 void
@@ -1325,11 +1304,6 @@ nautilus_navigation_window_split_view_off (NautilusNavigationWindow *window)
 	}
 
 	nautilus_navigation_window_update_show_hide_menu_items (window);
-	/* remember in gconf */
-	if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE) &&
-	    eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE)) {
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_EXTRA_PANE, FALSE);
-	}
 }
 
 gboolean
